<div id="page">
  <div id="menu">
$MENU
  </div>
  <div id="dir">
$FILES
  </div>
  <div id="gallery">
    Indexed by <a href="http://legart.dk">Apache::Gallery</a> - Copyright &copy; 2001 Michael Legart
  </div>
</div>
