<div id="page">
  <div id="menu">
$MENU
  </div>
  <div id="picture">
    <table>
      <tr>
        <td colspan="3">
						<center class="nav">
						Viewing picture $NUMBER of $TOTAL at $RESOLUTION pixels<br>
            <img src="$SRC"><br>
            Size [ <a href="$URI?width=640">640</a> |
            <a href="$URI?width=800">800</a> |
            <a href="$URI?width=1024">1024</a> |
            <a href="$URI?width=1600">1600</a> |
            <a href="$URI?width=2048">2048</a> ]
          </center>
        </td>
      </tr>
      <tr>
        <td width="20%">$BACK</td>
        <td width="60%">
          <center>
            <table align="center" class="info">
              <tr>
                <td>
                  $COMMENT
                  Picture taken: $DATETIME<br>
                  Flash: $FLASH<br>
                </td>
              </tr>
            </table>
          </center>
        </td>
        <td align="right" width="20%">$NEXT</td>
      </tr>
    </table>
  </div>
  <div id="gallery">
    Indexed by <a href="http://legart.dk">Apache::Gallery</a> - Copyright &copy; 2001 Michael Legart
  </div>
</div>
